@@ -1,8 +1,7 @@
 """
 Caching framework.
 """
-
-__version__ = "0.2.2"
+__version__ = "0.4.0"
 
 from functools import wraps
 from importlib import import_module
@@ -12,8 +11,8 @@ from typing import Callable, List, Optional, cast, Type, TypeVar
 from .backends.base import BaseCache, CacheFunctionType
 from .config import DefaultConfig
 from .dependency import CacheDependency
-
-__all__ = ["redis_cache", "memory_cache", "cache", "CacheDecoratorType"]
+from .lru import LRUDict
+from .utils import UnsupportedError
 
 BackendCls = TypeVar("BackendCls", bound=BaseCache)
 
@@ -56,9 +55,28 @@ def cache(
     dependency: List[CacheDependency],
     **kwargs,
 ) -> CacheDecoratorType:
-    """
+    """The base function to creat a cache object like this::
 
+        @cache(
+            limit=1000,
+            expire=60,
+            is_method=False,
+            strict=True,
+            backend="cache_alchemy.backends.memory.MemoryCache",
+            dependency=[],
+        )
+        def f(x, y):
+            pass
+
+        # To clear cache
+        f.cache_clear()
+
+    :param int expire: expire time with an integer value used as seconds.
     :param bool is_method: If *True*, the first argument will be ignored in generate cache key.
+    :param bool strict: If *False*, make a cache key in a way that is flat as possible rather than
+                        as a nested and strict structure that would support partially cache clear.
+                        it means that f(x=1, y=2) will now be treated as a distinct call from
+                        f(y=2, x=1) which will be cached separately.
     """
     config = DefaultConfig.get_current_config()
     module_path, class_name = backend.rsplit(".", 1)
@@ -87,10 +105,17 @@ def cache(
         def wrapper(*args, **kwargs):
             return cache(*args, **kwargs)
 
-        def cache_clear(*args, **kwargs):
+        def cache_clear(*args, **kwargs) -> int:
             """Clear the cache and cache statistics"""
-            cache.cache_clear(args, kwargs)
-            CacheDependency.dependent_cache_clear(cache, args, kwargs)
+            if not strict and (args or kwargs):
+                raise UnsupportedError("fast hash not support pattern delete")
+
+            return sum(
+                [
+                    cache.cache_clear(args, kwargs),
+                    CacheDependency.dependent_cache_clear(cache, args, kwargs),
+                ]
+            )
 
         for item in dependency:
             item.cache_objects.add(cache)
@@ -106,7 +131,7 @@ def cache(
     return decorating_function
 
 
-def redis_cache(
+def json_cache(
     limit: Optional[int] = None,
     *,
     expire: Optional[int] = None,
@@ -120,7 +145,45 @@ def redis_cache(
         expire=expire,
         is_method=is_method,
         strict=strict,
-        backend=DefaultConfig.get_current_config().CACHE_ALCHEMY_REDIS_BACKEND,
+        backend=DefaultConfig.get_current_config().CACHE_ALCHEMY_JSON_BACKEND,
+        dependency=dependency or [],
+        **kwargs,
+    )
+
+
+def method_json_cache(
+    limit: Optional[int] = None,
+    *,
+    expire: Optional[int] = None,
+    strict: bool = False,
+    dependency: Optional[List[CacheDependency]] = None,
+    **kwargs,
+) -> CacheDecoratorType:
+    return cache(
+        limit=limit,
+        expire=expire,
+        is_method=True,
+        strict=strict,
+        backend=DefaultConfig.get_current_config().CACHE_ALCHEMY_JSON_BACKEND,
+        dependency=dependency or [],
+        **kwargs,
+    )
+
+
+def property_json_cache(
+    limit: Optional[int] = None,
+    *,
+    expire: Optional[int] = None,
+    strict: bool = False,
+    dependency: Optional[List[CacheDependency]] = None,
+    **kwargs,
+) -> CacheDecoratorType:
+    return cache(
+        limit=limit,
+        expire=expire,
+        is_method=True,
+        strict=strict,
+        backend=DefaultConfig.get_current_config().CACHE_ALCHEMY_JSON_BACKEND,
         dependency=dependency or [],
         **kwargs,
     )
@@ -165,25 +228,6 @@ def method_memory_cache(
     )
 
 
-def method_redis_cache(
-    limit: Optional[int] = None,
-    *,
-    expire: Optional[int] = None,
-    strict: bool = False,
-    dependency: Optional[List[CacheDependency]] = None,
-    **kwargs,
-) -> CacheDecoratorType:
-    return cache(
-        limit=limit,
-        expire=expire,
-        is_method=True,
-        strict=strict,
-        backend=DefaultConfig.get_current_config().CACHE_ALCHEMY_REDIS_BACKEND,
-        dependency=dependency or [],
-        **kwargs,
-    )
-
-
 def property_memory_cache(
     limit: Optional[int] = None,
     *,
@@ -203,7 +247,27 @@ def property_memory_cache(
     )
 
 
-def property_redis_cache(
+def pickle_cache(
+    limit: Optional[int] = None,
+    *,
+    expire: Optional[int] = None,
+    is_method: bool = False,
+    strict: bool = False,
+    dependency: Optional[List[CacheDependency]] = None,
+    **kwargs,
+) -> CacheDecoratorType:
+    return cache(
+        limit=limit,
+        expire=expire,
+        is_method=is_method,
+        strict=strict,
+        backend=DefaultConfig.get_current_config().CACHE_ALCHEMY_PICKLE_BACKEND,
+        dependency=dependency or [],
+        **kwargs,
+    )
+
+
+def method_pickle_cache(
     limit: Optional[int] = None,
     *,
     expire: Optional[int] = None,
@@ -216,7 +280,26 @@ def property_redis_cache(
         expire=expire,
         is_method=True,
         strict=strict,
-        backend=DefaultConfig.get_current_config().CACHE_ALCHEMY_REDIS_BACKEND,
+        backend=DefaultConfig.get_current_config().CACHE_ALCHEMY_PICKLE_BACKEND,
+        dependency=dependency or [],
+        **kwargs,
+    )
+
+
+def property_pickle_cache(
+    limit: Optional[int] = None,
+    *,
+    expire: Optional[int] = None,
+    strict: bool = False,
+    dependency: Optional[List[CacheDependency]] = None,
+    **kwargs,
+) -> CacheDecoratorType:
+    return cache(
+        limit=limit,
+        expire=expire,
+        is_method=True,
+        strict=strict,
+        backend=DefaultConfig.get_current_config().CACHE_ALCHEMY_PICKLE_BACKEND,
         dependency=dependency or [],
         **kwargs,
     )
