@@ -4,7 +4,7 @@ from weakref import ref
 from configalchemy import BaseConfig
 
 if TYPE_CHECKING:  # pragma: no cover
-    from redis import StrictRedis
+    from redis import Redis
 
 _current_config_ref = ref(object)
 
@@ -12,9 +12,13 @@ _current_config_ref = ref(object)
 class DefaultConfig(BaseConfig):
     #: default redis url
     CACHE_ALCHEMY_REDIS_URL = "redis://127.0.0.1:6379/0"
-    #: redis cache backend - default: distributed cache which need assign client to config
-    CACHE_ALCHEMY_REDIS_BACKEND = "cache_alchemy.backends.redis.DistributedCache"
-    #: redis memory backend - default: distributed cache which need assign client to config
+    #: distributed json cache backend - default: distributed cache which need assign client to config
+    CACHE_ALCHEMY_JSON_BACKEND = "cache_alchemy.backends.json.DistributedJsonCache"
+    #: memory cache backend - default: distributed cache which need assign client to config
+    CACHE_ALCHEMY_PICKLE_BACKEND = (
+        "cache_alchemy.backends.pickle.DistributedPickleCache"
+    )
+    #: memory cache backend - default: distributed cache which need assign client to config
     CACHE_ALCHEMY_MEMORY_BACKEND = (
         "cache_alchemy.backends.memory.DistributedMemoryCache"
     )
@@ -27,7 +31,7 @@ class DefaultConfig(BaseConfig):
     CACHE_ALCHEMY_DEFAULT_EXPIRE = 60 * 60 * 24
 
     #: Need to be assigned after init, if use distributed cache
-    cache_redis_client: "StrictRedis"
+    cache_redis_client: "Redis"
 
     def __init__(self):
         super().__init__()
