@@ -8,6 +8,7 @@ from cache_alchemy.utils import (
     generate_strict_key_pattern,
     UnsupportedError,
     generate_fast_key_pattern,
+    escape,
 )
 
 
@@ -26,8 +27,8 @@ class UtilsTestCase(unittest.TestCase):
             ("", dict(args=(), kwargs=dict(), func=lambda *a: ...)),
             ("a01", dict(args=(1,), kwargs=dict(), func=lambda *a: ...)),
             ("a01a12", dict(args=(1, 2), kwargs=dict(), func=lambda *a: ...)),
-            ("a1b2", dict(args=(), kwargs=dict(a="1", b=2), func=lambda **k: ...)),
-            ("a1", dict(args=(), kwargs=dict(a="1"), func=lambda **k: ...)),
+            ("a'1'b2", dict(args=(), kwargs=dict(a="1", b=2), func=lambda **k: ...)),
+            ("a'1'", dict(args=(), kwargs=dict(a="1"), func=lambda **k: ...)),
             ("", dict(args=(), kwargs=dict(), func=lambda **k: ...)),
             ("a01a12b2", dict(args=(1, 2), kwargs=dict(b=2), func=lambda *a, **k: ...)),
             ("a1b1", dict(args=(1,), kwargs=dict(), func=lambda a, b=1: ...)),
@@ -99,15 +100,15 @@ class UtilsTestCase(unittest.TestCase):
                 ["a02a11"],
             ),
             (
-                "a1b2.*?",
+                "a'1'b2.*?",
                 dict(args=(), kwargs=dict(a="1", b=2), func=lambda **k: ...),
-                ["a1b2c3"],
-                ["a2b2c3"],
+                ["a'1'b2c3"],
+                ["a'2'b2c3"],
             ),
             (
-                "a1.*?",
+                "a'1'.*?",
                 dict(args=(), kwargs=dict(a="1"), func=lambda **k: ...),
-                ["a1b2c3"],
+                ["a'1'b2c3"],
                 ["a2b2"],
             ),
             (
@@ -171,13 +172,13 @@ class UtilsTestCase(unittest.TestCase):
                 ["a2b2"],
             ),
             (
-                f"cls{re.escape(str(Tmp))}a1b.*?",
+                f"cls{escape(str(Tmp))}a1b.*?",
                 dict(args=(Tmp, 1), kwargs=dict(), func=tmp.tmp_class_method.__func__),
                 [f"cls{Tmp}a1b1"],
                 [f"cls{Tmp}a2b1"],
             ),
             (
-                f"cls{re.escape(str(Tmp))}a1b2",
+                f"cls{escape(str(Tmp))}a1b2",
                 dict(
                     args=(Tmp, 1), kwargs=dict(b=2), func=tmp.tmp_class_method.__func__
                 ),
